/*
 * Codepage definitions for libagdb
 *
 * Copyright (C) 2014-2018, Joachim Metz <joachim.metz@gmail.com>
 *
 * Refer to AUTHORS for acknowledgements.
 *
 * This software is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */

#if !defined( _LIBAGDB_CODEPAGE_H )
#define _LIBAGDB_CODEPAGE_H

#include <libagdb/types.h>

#if defined( __cplusplus )
extern "C" {
#endif

/* The codepage definitions
 */
enum LIBAGDB_CODEPAGES
{
	LIBAGDB_CODEPAGE_ASCII				= 20127,

	LIBAGDB_CODEPAGE_ISO_8859_1			= 28591,
	LIBAGDB_CODEPAGE_ISO_8859_2			= 28592,
	LIBAGDB_CODEPAGE_ISO_8859_3			= 28593,
	LIBAGDB_CODEPAGE_ISO_8859_4			= 28594,
	LIBAGDB_CODEPAGE_ISO_8859_5			= 28595,
	LIBAGDB_CODEPAGE_ISO_8859_6			= 28596,
	LIBAGDB_CODEPAGE_ISO_8859_7			= 28597,
	LIBAGDB_CODEPAGE_ISO_8859_8			= 28598,
	LIBAGDB_CODEPAGE_ISO_8859_9			= 28599,
	LIBAGDB_CODEPAGE_ISO_8859_10			= 28600,
	LIBAGDB_CODEPAGE_ISO_8859_11			= 28601,
	LIBAGDB_CODEPAGE_ISO_8859_13			= 28603,
	LIBAGDB_CODEPAGE_ISO_8859_14			= 28604,
	LIBAGDB_CODEPAGE_ISO_8859_15			= 28605,
	LIBAGDB_CODEPAGE_ISO_8859_16			= 28606,

	LIBAGDB_CODEPAGE_KOI8_R				= 20866,
	LIBAGDB_CODEPAGE_KOI8_U				= 21866,

	LIBAGDB_CODEPAGE_WINDOWS_874			= 874,
	LIBAGDB_CODEPAGE_WINDOWS_932			= 932,
	LIBAGDB_CODEPAGE_WINDOWS_936			= 936,
	LIBAGDB_CODEPAGE_WINDOWS_949			= 949,
	LIBAGDB_CODEPAGE_WINDOWS_950			= 950,
	LIBAGDB_CODEPAGE_WINDOWS_1250			= 1250,
	LIBAGDB_CODEPAGE_WINDOWS_1251			= 1251,
	LIBAGDB_CODEPAGE_WINDOWS_1252			= 1252,
	LIBAGDB_CODEPAGE_WINDOWS_1253			= 1253,
	LIBAGDB_CODEPAGE_WINDOWS_1254			= 1254,
	LIBAGDB_CODEPAGE_WINDOWS_1255			= 1255,
	LIBAGDB_CODEPAGE_WINDOWS_1256			= 1256,
	LIBAGDB_CODEPAGE_WINDOWS_1257			= 1257,
	LIBAGDB_CODEPAGE_WINDOWS_1258			= 1258
};

#define LIBAGDB_CODEPAGE_US_ASCII			LIBAGDB_CODEPAGE_ASCII

#define LIBAGDB_CODEPAGE_ISO_WESTERN_EUROPEAN		LIBAGDB_CODEPAGE_ISO_8859_1
#define LIBAGDB_CODEPAGE_ISO_CENTRAL_EUROPEAN		LIBAGDB_CODEPAGE_ISO_8859_2
#define LIBAGDB_CODEPAGE_ISO_SOUTH_EUROPEAN		LIBAGDB_CODEPAGE_ISO_8859_3
#define LIBAGDB_CODEPAGE_ISO_NORTH_EUROPEAN		LIBAGDB_CODEPAGE_ISO_8859_4
#define LIBAGDB_CODEPAGE_ISO_CYRILLIC			LIBAGDB_CODEPAGE_ISO_8859_5
#define LIBAGDB_CODEPAGE_ISO_ARABIC			LIBAGDB_CODEPAGE_ISO_8859_6
#define LIBAGDB_CODEPAGE_ISO_GREEK			LIBAGDB_CODEPAGE_ISO_8859_7
#define LIBAGDB_CODEPAGE_ISO_HEBREW			LIBAGDB_CODEPAGE_ISO_8859_8
#define LIBAGDB_CODEPAGE_ISO_TURKISH			LIBAGDB_CODEPAGE_ISO_8859_9
#define LIBAGDB_CODEPAGE_ISO_NORDIC			LIBAGDB_CODEPAGE_ISO_8859_10
#define LIBAGDB_CODEPAGE_ISO_THAI			LIBAGDB_CODEPAGE_ISO_8859_11
#define LIBAGDB_CODEPAGE_ISO_BALTIC			LIBAGDB_CODEPAGE_ISO_8859_13
#define LIBAGDB_CODEPAGE_ISO_CELTIC			LIBAGDB_CODEPAGE_ISO_8859_14

#define LIBAGDB_CODEPAGE_ISO_LATIN_1			LIBAGDB_CODEPAGE_ISO_8859_1
#define LIBAGDB_CODEPAGE_ISO_LATIN_2			LIBAGDB_CODEPAGE_ISO_8859_2
#define LIBAGDB_CODEPAGE_ISO_LATIN_3			LIBAGDB_CODEPAGE_ISO_8859_3
#define LIBAGDB_CODEPAGE_ISO_LATIN_4			LIBAGDB_CODEPAGE_ISO_8859_4
#define LIBAGDB_CODEPAGE_ISO_LATIN_5			LIBAGDB_CODEPAGE_ISO_8859_9
#define LIBAGDB_CODEPAGE_ISO_LATIN_6			LIBAGDB_CODEPAGE_ISO_8859_10
#define LIBAGDB_CODEPAGE_ISO_LATIN_7			LIBAGDB_CODEPAGE_ISO_8859_13
#define LIBAGDB_CODEPAGE_ISO_LATIN_8			LIBAGDB_CODEPAGE_ISO_8859_14
#define LIBAGDB_CODEPAGE_ISO_LATIN_9			LIBAGDB_CODEPAGE_ISO_8859_15
#define LIBAGDB_CODEPAGE_ISO_LATIN_10			LIBAGDB_CODEPAGE_ISO_8859_16

#define LIBAGDB_CODEPAGE_KOI8_RUSSIAN			LIBAGDB_CODEPAGE_KOI8_R
#define LIBAGDB_CODEPAGE_KOI8_UKRAINIAN			LIBAGDB_CODEPAGE_KOI8_U

#define LIBAGDB_CODEPAGE_WINDOWS_THAI			LIBAGDB_CODEPAGE_WINDOWS_874
#define LIBAGDB_CODEPAGE_WINDOWS_JAPANESE		LIBAGDB_CODEPAGE_WINDOWS_932
#define LIBAGDB_CODEPAGE_WINDOWS_CHINESE_SIMPLIFIED	LIBAGDB_CODEPAGE_WINDOWS_936
#define LIBAGDB_CODEPAGE_WINDOWS_KOREAN			LIBAGDB_CODEPAGE_WINDOWS_949
#define LIBAGDB_CODEPAGE_WINDOWS_CHINESE_TRADITIONAL	LIBAGDB_CODEPAGE_WINDOWS_950
#define LIBAGDB_CODEPAGE_WINDOWS_CENTRAL_EUROPEAN	LIBAGDB_CODEPAGE_WINDOWS_1250
#define LIBAGDB_CODEPAGE_WINDOWS_CYRILLIC		LIBAGDB_CODEPAGE_WINDOWS_1251
#define LIBAGDB_CODEPAGE_WINDOWS_WESTERN_EUROPEAN	LIBAGDB_CODEPAGE_WINDOWS_1252
#define LIBAGDB_CODEPAGE_WINDOWS_GREEK			LIBAGDB_CODEPAGE_WINDOWS_1253
#define LIBAGDB_CODEPAGE_WINDOWS_TURKISH		LIBAGDB_CODEPAGE_WINDOWS_1254
#define LIBAGDB_CODEPAGE_WINDOWS_HEBREW			LIBAGDB_CODEPAGE_WINDOWS_1255
#define LIBAGDB_CODEPAGE_WINDOWS_ARABIC			LIBAGDB_CODEPAGE_WINDOWS_1256
#define LIBAGDB_CODEPAGE_WINDOWS_BALTIC			LIBAGDB_CODEPAGE_WINDOWS_1257
#define LIBAGDB_CODEPAGE_WINDOWS_VIETNAMESE		LIBAGDB_CODEPAGE_WINDOWS_1258

#if defined( __cplusplus )
}
#endif

#endif /* !defined( _LIBAGDB_CODEPAGE_H ) */

